==> client-notifications-3.714.0.tgz: package/dist-es/models/models_0.js <==
import { NotificationsServiceException as __BaseException } from "./NotificationsServiceException";
export class AccessDeniedException extends __BaseException {
    constructor(opts) {
        super({
            name: "AccessDeniedException",
            $fault: "client",
            ...opts,
        });
        this.name = "AccessDeniedException";
        this.$fault = "client";
        Object.setPrototypeOf(this, AccessDeniedException.prototype);
    }
}
export const AggregationDuration = {
    LONG: "LONG",
    NONE: "NONE",
    SHORT: "SHORT",
};
export const AggregationEventType = {
    AGGREGATE: "AGGREGATE",
    CHILD: "CHILD",
    NONE: "NONE",
};
export class ConflictException extends __BaseException {
    constructor(opts) {
        super({
            name: "ConflictException",
            $fault: "client",
            ...opts,
        });
        this.name = "ConflictException";
        this.$fault = "client";
        Object.setPrototypeOf(this, ConflictException.prototype);
        this.resourceId = opts.resourceId;
    }
}
export class InternalServerException extends __BaseException {
    constructor(opts) {
        super({
            name: "InternalServerException",
            $fault: "server",
            ...opts,
        });
        this.name = "InternalServerException";
        this.$fault = "server";
        this.$retryable = {};
        Object.setPrototypeOf(this, InternalServerException.prototype);
    }
}
export class ResourceNotFoundException extends __BaseException {
    constructor(opts) {
        super({
            name: "ResourceNotFoundException",
            $fault: "client",
            ...opts,
        });
        this.name = "ResourceNotFoundException";
        this.$fault = "client";
        Object.setPrototypeOf(this, ResourceNotFoundException.prototype);
        this.resourceId = opts.resourceId;
    }
}
export class ServiceQuotaExceededException extends __BaseException {
    constructor(opts) {
        super({
            name: "ServiceQuotaExceededException",
            $fault: "client",
            ...opts,
        });
        this.name = "ServiceQuotaExceededException";
        this.$fault = "client";
        Object.setPrototypeOf(this, ServiceQuotaExceededException.prototype);
        this.resourceType = opts.resourceType;
        this.resourceId = opts.resourceId;
        this.serviceCode = opts.serviceCode;
        this.quotaCode = opts.quotaCode;
    }
}
export class ThrottlingException extends __BaseException {
    constructor(opts) {
        super({
            name: "ThrottlingException",
            $fault: "client",
            ...opts,
        });
        this.name = "ThrottlingException";
        this.$fault = "client";
        this.$retryable = {
            throttling: true,
        };
        Object.setPrototypeOf(this, ThrottlingException.prototype);
        this.serviceCode = opts.serviceCode;
        this.quotaCode = opts.quotaCode;
        this.retryAfterSeconds = opts.retryAfterSeconds;
    }
}
export const ValidationExceptionReason = {
    FIELD_VALIDATION_FAILED: "fieldValidationFailed",
    OTHER: "other",
};
export class ValidationException extends __BaseException {
    constructor(opts) {
        super({
            name: "ValidationException",
            $fault: "client",
            ...opts,
        });
        this.name = "ValidationException";
        this.$fault = "client";
        Object.setPrototypeOf(this, ValidationException.prototype);
        this.reason = opts.reason;
        this.fieldList = opts.fieldList;
    }
}
export const EventRuleStatus = {
    ACTIVE: "ACTIVE",
    CREATING: "CREATING",
    DELETING: "DELETING",
    INACTIVE: "INACTIVE",
    UPDATING: "UPDATING",
};
export const NotificationConfigurationStatus = {
    ACTIVE: "ACTIVE",
    DELETING: "DELETING",
    INACTIVE: "INACTIVE",
    PARTIALLY_ACTIVE: "PARTIALLY_ACTIVE",
};
export const NotificationHubStatus = {
    ACTIVE: "ACTIVE",
    DEREGISTERING: "DEREGISTERING",
    INACTIVE: "INACTIVE",
    REGISTERING: "REGISTERING",
};
export const EventStatus = {
    HEALTHY: "HEALTHY",
    UNHEALTHY: "UNHEALTHY",
};
export const LocaleCode = {
    de_DE: "de_DE",
    en_CA: "en_CA",
    en_UK: "en_UK",
    en_US: "en_US",
    es_ES: "es_ES",
    fr_CA: "fr_CA",
    fr_FR: "fr_FR",
    id_ID: "id_ID",
    it_IT: "it_IT",
    ja_JP: "ja_JP",
    ko_KR: "ko_KR",
    pt_BR: "pt_BR",
    tr_TR: "tr_TR",
    zh_CN: "zh_CN",
    zh_TW: "zh_TW",
};
export const MediaElementType = {
    IMAGE: "IMAGE",
};
export const NotificationType = {
    ALERT: "ALERT",
    ANNOUNCEMENT: "ANNOUNCEMENT",
    INFORMATIONAL: "INFORMATIONAL",
    WARNING: "WARNING",
};
export const SchemaVersion = {
    SCHEMA_VERSION_1_0: "v1.0",
};
export const TextPartType = {
    LOCALIZED_TEXT: "LOCALIZED_TEXT",
    PLAIN_TEXT: "PLAIN_TEXT",
    URL: "URL",
};

==> client-notifications-3.726.1.tgz: package/dist-es/models/models_0.js <==
import { NotificationsServiceException as __BaseException } from "./NotificationsServiceException";
export class AccessDeniedException extends __BaseException {
    name = "AccessDeniedException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "AccessDeniedException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, AccessDeniedException.prototype);
    }
}
export const AggregationDuration = {
    LONG: "LONG",
    NONE: "NONE",
    SHORT: "SHORT",
};
export const AggregationEventType = {
    AGGREGATE: "AGGREGATE",
    CHILD: "CHILD",
    NONE: "NONE",
};
export class ConflictException extends __BaseException {
    name = "ConflictException";
    $fault = "client";
    resourceId;
    constructor(opts) {
        super({
            name: "ConflictException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, ConflictException.prototype);
        this.resourceId = opts.resourceId;
    }
}
export class InternalServerException extends __BaseException {
    name = "InternalServerException";
    $fault = "server";
    $retryable = {};
    constructor(opts) {
        super({
            name: "InternalServerException",
            $fault: "server",
            ...opts,
        });
        Object.setPrototypeOf(this, InternalServerException.prototype);
    }
}
export class ResourceNotFoundException extends __BaseException {
    name = "ResourceNotFoundException";
    $fault = "client";
    resourceId;
    constructor(opts) {
        super({
            name: "ResourceNotFoundException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, ResourceNotFoundException.prototype);
        this.resourceId = opts.resourceId;
    }
}
export class ServiceQuotaExceededException extends __BaseException {
    name = "ServiceQuotaExceededException";
    $fault = "client";
    resourceType;
    resourceId;
    serviceCode;
    quotaCode;
    constructor(opts) {
        super({
            name: "ServiceQuotaExceededException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, ServiceQuotaExceededException.prototype);
        this.resourceType = opts.resourceType;
        this.resourceId = opts.resourceId;
        this.serviceCode = opts.serviceCode;
        this.quotaCode = opts.quotaCode;
    }
}
export class ThrottlingException extends __BaseException {
    name = "ThrottlingException";
    $fault = "client";
    $retryable = {
        throttling: true,
    };
    serviceCode;
    quotaCode;
    retryAfterSeconds;
    constructor(opts) {
        super({
            name: "ThrottlingException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, ThrottlingException.prototype);
        this.serviceCode = opts.serviceCode;
        this.quotaCode = opts.quotaCode;
        this.retryAfterSeconds = opts.retryAfterSeconds;
    }
}
export const ValidationExceptionReason = {
    FIELD_VALIDATION_FAILED: "fieldValidationFailed",
    OTHER: "other",
};
export class ValidationException extends __BaseException {
    name = "ValidationException";
    $fault = "client";
    reason;
    fieldList;
    constructor(opts) {
        super({
            name: "ValidationException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, ValidationException.prototype);
        this.reason = opts.reason;
        this.fieldList = opts.fieldList;
    }
}
export const EventRuleStatus = {
    ACTIVE: "ACTIVE",
    CREATING: "CREATING",
    DELETING: "DELETING",
    INACTIVE: "INACTIVE",
    UPDATING: "UPDATING",
};
export const NotificationConfigurationStatus = {
    ACTIVE: "ACTIVE",
    DELETING: "DELETING",
    INACTIVE: "INACTIVE",
    PARTIALLY_ACTIVE: "PARTIALLY_ACTIVE",
};
export const NotificationHubStatus = {
    ACTIVE: "ACTIVE",
    DEREGISTERING: "DEREGISTERING",
    INACTIVE: "INACTIVE",
    REGISTERING: "REGISTERING",
};
export const EventStatus = {
    HEALTHY: "HEALTHY",
    UNHEALTHY: "UNHEALTHY",
};
export const LocaleCode = {
    de_DE: "de_DE",
    en_CA: "en_CA",
    en_UK: "en_UK",
    en_US: "en_US",
    es_ES: "es_ES",
    fr_CA: "fr_CA",
    fr_FR: "fr_FR",
    id_ID: "id_ID",
    it_IT: "it_IT",
    ja_JP: "ja_JP",
    ko_KR: "ko_KR",
    pt_BR: "pt_BR",
    tr_TR: "tr_TR",
    zh_CN: "zh_CN",
    zh_TW: "zh_TW",
};
export const MediaElementType = {
    IMAGE: "IMAGE",
};
export const NotificationType = {
    ALERT: "ALERT",
    ANNOUNCEMENT: "ANNOUNCEMENT",
    INFORMATIONAL: "INFORMATIONAL",
    WARNING: "WARNING",
};
export const SchemaVersion = {
    SCHEMA_VERSION_1_0: "v1.0",
};
export const TextPartType = {
    LOCALIZED_TEXT: "LOCALIZED_TEXT",
    PLAIN_TEXT: "PLAIN_TEXT",
    URL: "URL",
};
